# Change Log
All notable changes to this project will be documented in this file.
This project adheres to [Semantic Versioning](http://semver.org/).

## [0.0.3] - 2021-01-15
- Fixes bugs in configuration and zenodo files
- Added pysat version restriction to requirements.txt

## [0.0.2] - 2021-01-11
- Added real-time ACE instrument
- Fixed bugs and restructured code to comply with changes in pysat-3.0
- Added user documentation
- Simplified setup and testing environments
- Separated space weather methods into sub-modules by instrument

## [0.0.1] - 2020-08-13
- Initial port of existing routines from pysat
